==> apache-cxf-3.1.16-src.zip: apache-cxf-3.1.16-src/rt/features/metrics/src/main/java/org/apache/cxf/metrics/interceptors/MetricsMessageInPreInvokeInterceptor.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.metrics.interceptors;

import org.apache.cxf.interceptor.Fault;
import org.apache.cxf.message.Exchange;
import org.apache.cxf.message.Message;
import org.apache.cxf.metrics.ExchangeMetrics;
import org.apache.cxf.metrics.MetricsProvider;
import org.apache.cxf.phase.Phase;

public class MetricsMessageInPreInvokeInterceptor extends AbstractMetricsInterceptor {

    public MetricsMessageInPreInvokeInterceptor(MetricsProvider p[]) {
        super(Phase.PRE_INVOKE, p);
    }

    public void handleMessage(Message message) throws Fault {
        if (!isRequestor(message)) {
            Exchange ex = message.getExchange();
            //we now know the operation, start metrics for it
            ExchangeMetrics ctx = getExchangeMetrics(message, false);
            if (ctx != null) {
                addOperationMetrics(ctx, message, ex.getBindingOperationInfo());
            }
        }
    }               
}

==> apache-cxf-3.5.8-src.zip: apache-cxf-3.5.8-src/rt/features/metrics/src/main/java/org/apache/cxf/metrics/interceptors/MetricsMessageInPreInvokeInterceptor.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.metrics.interceptors;

import org.apache.cxf.interceptor.Fault;
import org.apache.cxf.message.Exchange;
import org.apache.cxf.message.Message;
import org.apache.cxf.metrics.ExchangeMetrics;
import org.apache.cxf.metrics.MetricsProvider;
import org.apache.cxf.phase.Phase;

public class MetricsMessageInPreInvokeInterceptor extends AbstractMetricsInterceptor {

    public MetricsMessageInPreInvokeInterceptor(MetricsProvider[] p) {
        super(Phase.PRE_INVOKE, p);
    }

    public void handleMessage(Message message) throws Fault {
        if (!isRequestor(message)) {
            Exchange ex = message.getExchange();
            //we now know the operation, start metrics for it
            ExchangeMetrics ctx = getExchangeMetrics(message, false);
            if (ctx != null) {
                addOperationMetrics(ctx, message, ex.getBindingOperationInfo());
            }
        }
    }
}
